@@ -7,6 +7,4 @@ class SessionMiddleware(DjSessionMiddleware):
         # SESSION_COOKIE_NAME can be change by developers
         # https://docs.djangoproject.com/en/3.2/ref/settings/#session-cookie-name
         session_key = request.COOKIES.get(settings.SESSION_COOKIE_NAME)
-        request.session = self.SessionStore(
-            session_key=session_key,
-        )
\ No newline at end of file
+        request.session = self.SessionStore(session_key=session_key)
